mafw
====

.. automodule:: mafw

   
   .. rubric:: Module Attributes

   .. autosummary::
   
      mafw_hookimpl
   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   active
   db
   decorators
   enumerators
   examples
   hookspecs
   mafw_errors
   plugin_manager
   plugins
   processor
   processor_library
   runner
   scripts
   timer
   tools
   ui
